@@ -88,6 +88,9 @@ def run(project_id: str, notebook_id: str, run_id: str):
             kernel_name="python3",
             log_output=True,
         )
+    except Exception as ex:
+        print(f"Run failed!")
+        raise ex
     finally:
         cancel_interval()
         save_artifacts()
