@@ -15,7 +15,7 @@ from treebeard.helper import (
     get_service_status_message,
 )
 from treebeard.notebooks.commands import cancel, run, status
-from treebeard.other.commands import configure, info, version
+from treebeard.other.commands import configure, info, setup, version
 from treebeard.secrets.commands import secrets
 
 msg = get_service_status_message(service_status_endpoint)
@@ -48,5 +48,6 @@ cli.add_command(status)
 cli.add_command(run)
 cli.add_command(cancel)
 cli.add_command(secrets)
+cli.add_command(setup)
 cli.add_command(info)
 cli.add_command(version)
